@@ -976,7 +976,7 @@ class Api(PushEventSource):
         try:
             path_method_body = dict_deep_get(source_body_paths, [self.Path, self.Method]) or {}
         except InvalidValueType as e:
-            raise InvalidResourceException(api_id, f"Property 'DefinitionBody' is invalid: {str(e)}") from e
+            raise InvalidResourceException(api_id, f"Property 'DefinitionBody' is invalid: {e!s}") from e
 
         sam_expect(path_method_body, api_id, f"DefinitionBody.paths.{self.Path}.{self.Method}").to_be_a_map()
 
